@@ -21,6 +21,7 @@
 import datetime
 import itertools
 import json
+import zoneinfo
 
 import croniter
 from oslo_config import cfg
@@ -36,14 +37,6 @@ import wsme
 from wsme import types as wtypes
 import wsmeext.pecan as wsme_pecan
 
-try:
-    import zoneinfo
-except ImportError:
-    # zoneinfo is available in Python >= 3.9
-    import pytz
-    import pytz.exceptions
-    zoneinfo = None
-
 import aodh
 from aodh.api.controllers.v2 import base
 from aodh.api.controllers.v2 import utils as v2_utils
@@ -83,11 +76,11 @@ severity_kind_enum = wtypes.Enum(str, *severity_kind)
 ALARM_REASON_DEFAULT = "Not evaluated yet"
 ALARM_REASON_MANUAL = "Manually set via API"
 
-ALARM_QUERY_FIELDS_ALLOWED = set([
+ALARM_QUERY_FIELDS_ALLOWED = {
     'all_projects', 'user_id', 'project_id', 'type', 'name', 'enabled',
     'state', 'severity', 'timestamp', 'repeat_actions'
-])
-ALARM_QUERY_OPS_ALLOWED = set(['eq'])
+}
+ALARM_QUERY_OPS_ALLOWED = {'eq'}
 
 
 class OverQuota(base.ClientSideError):
@@ -96,7 +89,7 @@ class OverQuota(base.ClientSideError):
             'u': data.user_id,
             'p': data.project_id
         }
-        super(OverQuota, self).__init__(
+        super().__init__(
             _("Alarm quota exceeded for user %(u)s on project %(p)s") % d,
             status_code=403)
 
@@ -182,12 +175,9 @@ class AlarmTimeConstraint(base.Base):
     @staticmethod
     def validate(tc):
         if tc.timezone:
-            checker = zoneinfo.ZoneInfo if zoneinfo else pytz.timezone
-            exc = (zoneinfo.ZoneInfoNotFoundError if zoneinfo else
-                   pytz.exceptions.UnknownTimeZoneError)
             try:
-                checker(tc.timezone)
-            except exc:
+                zoneinfo.ZoneInfo(tc.timezone)
+            except zoneinfo.ZoneInfoNotFoundError:
                 raise base.ClientSideError(_("Timezone %s is not valid")
                                            % tc.timezone)
         return tc
@@ -202,7 +192,7 @@ class AlarmTimeConstraint(base.Base):
 
 
 ALARMS_RULES = extension.ExtensionManager("aodh.alarm.rule")
-LOG.debug("alarm rules plugin loaded: %s" % ",".join(ALARMS_RULES.names()))
+LOG.debug("alarm rules plugin loaded: %s", ",".join(ALARMS_RULES.names()))
 
 ACTIONS_SCHEMA = extension.ExtensionManager(
     notifier.AlarmNotifierService.NOTIFIER_EXTENSIONS_NAMESPACE).names()
@@ -286,7 +276,7 @@ class Alarm(base.Base):
     "The latest alarm evaluation time"
 
     def __init__(self, rule=None, time_constraints=None, **kwargs):
-        super(Alarm, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         if rule:
             setattr(self, '%s_rule' % self.type,
@@ -366,7 +356,7 @@ class Alarm(base.Base):
                                             "maximum": max_actions}
                 raise base.ClientSideError(error)
 
-            limited = rbac.get_limited_to_project(pecan.request.headers,
+            limited = rbac.get_limited_to_project(pecan.request,
                                                   pecan.request.enforcer)
 
             for action in actions:
@@ -405,7 +395,7 @@ class Alarm(base.Base):
                    )
 
     def as_dict(self, db_model):
-        d = super(Alarm, self).as_dict(db_model)
+        d = super().as_dict(db_model)
         for k in d:
             if k.endswith('_rule'):
                 del d[k]
@@ -479,7 +469,7 @@ class Alarm(base.Base):
                         else:
                             pw = ':delete'
                             trust_id_used = True
-                        netloc = '%s%s@%s' % (trust_id, pw, url.netloc)
+                        netloc = '{}{}@{}'.format(trust_id, pw, url.netloc)
                         url = urlparse.SplitResult(url.scheme, netloc,
                                                    url.path, url.query,
                                                    url.fragment)
@@ -556,9 +546,9 @@ def _send_notification(event, payload):
 
 def stringify_timestamps(data):
     """Stringify any datetimes in given dict."""
-    return dict((k, v.isoformat()
-                 if isinstance(v, datetime.datetime) else v)
-                for (k, v) in data.items())
+    return {k: v.isoformat()
+            if isinstance(v, datetime.datetime) else v
+            for (k, v) in data.items()}
 
 
 @profiler.trace_cls('api')
@@ -578,7 +568,8 @@ class AlarmController(rest.RestController):
         auth_project = pecan.request.headers.get('X-Project-Id')
 
         filters = {'alarm_id': self._id}
-        if not rbac.is_admin(pecan.request.headers):
+        is_admin = rbac.is_admin(pecan.request, pecan.request.enforcer)
+        if not is_admin:
             filters['project_id'] = auth_project
 
         alarms = pecan.request.storage.get_alarms(**filters)
@@ -588,7 +579,7 @@ class AlarmController(rest.RestController):
         alarm = alarms[0]
         target = {'user_id': alarm.user_id,
                   'project_id': alarm.project_id}
-        rbac.enforce(rbac_directive, pecan.request.headers,
+        rbac.enforce(rbac_directive, pecan.request,
                      pecan.request.enforcer, target)
         return alarm
 
@@ -662,7 +653,7 @@ class AlarmController(rest.RestController):
 
         data.alarm_id = self._id
 
-        user, project = rbac.get_limited_to(pecan.request.headers,
+        user, project = rbac.get_limited_to(pecan.request,
                                             pecan.request.enforcer)
         if user:
             data.user_id = user
@@ -694,9 +685,9 @@ class AlarmController(rest.RestController):
 
         alarm = pecan.request.storage.update_alarm(alarm_in)
 
-        change = dict((k, v) for k, v in updated_alarm.items()
-                      if v != old_alarm[k] and k not in
-                      ['timestamp', 'state_timestamp'])
+        change = {k: v for k, v in updated_alarm.items()
+                  if v != old_alarm[k] and k not in
+                  ['timestamp', 'state_timestamp']}
         self._record_change(change, now, on_behalf_of=alarm.project_id)
         return Alarm.from_db_model_scrubbed(alarm)
 
@@ -727,7 +718,7 @@ class AlarmController(rest.RestController):
         # allow history to be returned for deleted alarms, but scope changes
         # returned to those carried out on behalf of the auth'd tenant, to
         # avoid inappropriate cross-tenant visibility of alarm history
-        auth_project = rbac.get_limited_to_project(pecan.request.headers,
+        auth_project = rbac.get_limited_to_project(pecan.request,
                                                    pecan.request.enforcer)
         conn = pecan.request.storage
         kwargs = v2_utils.query_to_kwargs(
@@ -813,14 +804,14 @@ class AlarmsController(rest.RestController):
 
         :param data: an alarm within the request body.
         """
-        rbac.enforce('create_alarm', pecan.request.headers,
+        rbac.enforce('create_alarm', pecan.request,
                      pecan.request.enforcer, {})
 
         conn = pecan.request.storage
         now = timeutils.utcnow()
 
         data.alarm_id = uuidutils.generate_uuid()
-        user_limit, project_limit = rbac.get_limited_to(pecan.request.headers,
+        user_limit, project_limit = rbac.get_limited_to(pecan.request,
                                                         pecan.request.enforcer)
 
         def _set_ownership(aspect, owner_limitation, header):
@@ -874,22 +865,22 @@ class AlarmsController(rest.RestController):
         :param marker: The pagination query marker.
         """
         target = rbac.target_from_segregation_rule(
-            pecan.request.headers, pecan.request.enforcer)
-        rbac.enforce('get_alarms', pecan.request.headers,
+            pecan.request, pecan.request.enforcer)
+        rbac.enforce('get_alarms', pecan.request,
                      pecan.request.enforcer, target)
 
         q = q or []
         filters = {}
 
         # Check field
-        keys = set([query.field for query in q])
+        keys = {query.field for query in q}
         if not keys.issubset(ALARM_QUERY_FIELDS_ALLOWED):
             raise wsme.exc.InvalidInput(
                 'field', keys,
                 'only fields %s are allowed' % ALARM_QUERY_FIELDS_ALLOWED
             )
         # Check op
-        ops = set([query.op for query in q])
+        ops = {query.op for query in q}
         if any([op not in ALARM_QUERY_OPS_ALLOWED for op in ops]):
             raise wsme.exc.InvalidInput(
                 'op', ops,
@@ -898,12 +889,12 @@ class AlarmsController(rest.RestController):
 
         if 'all_projects' in keys:
             if v2_utils.get_query_value(q, 'all_projects', 'boolean'):
-                rbac.enforce('get_alarms:all_projects', pecan.request.headers,
+                rbac.enforce('get_alarms:all_projects', pecan.request,
                              pecan.request.enforcer, target)
             keys.remove('all_projects')
         else:
             project_id = pecan.request.headers.get('X-Project-Id')
-            is_admin = rbac.is_admin(pecan.request.headers)
+            is_admin = rbac.is_admin(pecan.request, pecan.request.enforcer)
 
             if not v2_utils.is_field_exist(q, 'project_id'):
                 q.append(
