@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 # Copyright 2014 OpenStack Foundation
 # Copyright 2015 Red Hat, Inc.
@@ -16,32 +15,39 @@
 # under the License.
 
 import cotyledon
+from cotyledon import oslo_config_glue
+from oslo_log import log
 
 from aodh import evaluator as evaluator_svc
 from aodh import event as event_svc
 from aodh import notifier as notifier_svc
 from aodh import service
 
+LOG = log.getLogger(__name__)
+
 
 def notifier():
-    conf = service.prepare_service()
     sm = cotyledon.ServiceManager()
+    conf = service.prepare_service()
+    oslo_config_glue.setup(sm, conf)
     sm.add(notifier_svc.AlarmNotifierService,
            workers=conf.notifier.workers, args=(conf,))
     sm.run()
 
 
 def evaluator():
-    conf = service.prepare_service()
     sm = cotyledon.ServiceManager()
+    conf = service.prepare_service()
+    oslo_config_glue.setup(sm, conf)
     sm.add(evaluator_svc.AlarmEvaluationService,
            workers=conf.evaluator.workers, args=(conf,))
     sm.run()
 
 
 def listener():
-    conf = service.prepare_service()
     sm = cotyledon.ServiceManager()
+    conf = service.prepare_service()
+    oslo_config_glue.setup(sm, conf)
     sm.add(event_svc.EventAlarmEvaluationService,
            workers=conf.listener.workers, args=(conf,))
     sm.run()
