@@ -54,7 +54,7 @@ OPTS = [
 ]
 
 
-class Evaluator(object, metaclass=abc.ABCMeta):
+class Evaluator(metaclass=abc.ABCMeta):
     """Base class for alarm rule evaluator plugins."""
 
     def __init__(self, conf):
@@ -112,6 +112,11 @@ class Evaluator(object, metaclass=abc.ABCMeta):
         self.alarm_change_notifier.info({},
                                         notification, payload)
 
+    def _increment_evaluation_result(self, alarm_id, project_id, state):
+        if self.conf.enable_evaluation_results_metrics:
+            self._storage_conn.increment_alarm_counter(
+                alarm_id, project_id, state)
+
     def _refresh(self, alarm, state, reason, reason_data, always_record=False):
         """Refresh alarm state."""
         try:
@@ -193,7 +198,7 @@ class AlarmEvaluationService(cotyledon.Service):
     EVALUATOR_EXTENSIONS_NAMESPACE = "aodh.evaluator"
 
     def __init__(self, worker_id, conf):
-        super(AlarmEvaluationService, self).__init__(worker_id)
+        super().__init__(worker_id)
         self.conf = conf
 
         ef = lambda: futures.ThreadPoolExecutor(max_workers=10)  # noqa: E731
