@@ -13,7 +13,6 @@
 #
 
 from oslo_log import log
-import six
 import stevedore
 
 from aodh import evaluator
@@ -26,7 +25,7 @@ STATE_CHANGE = {evaluator.ALARM: 'outside their threshold.',
                 evaluator.UNKNOWN: 'state evaluated to unknown.'}
 
 
-class RuleTarget(object):
+class RuleTarget:
 
     def __init__(self, rule, rule_evaluator, rule_name):
         self.rule = rule
@@ -53,7 +52,7 @@ class RuleTarget(object):
             self.evaluated = True
 
 
-class RuleEvaluationBase(object):
+class RuleEvaluationBase:
     def __init__(self, rule_target):
         self.rule_target = rule_target
 
@@ -79,7 +78,7 @@ class AlarmEvaluation(RuleEvaluationBase):
     __nonzero__ = __bool__
 
 
-class AndOp(object):
+class AndOp:
     def __init__(self, rule_targets):
         self.rule_targets = rule_targets
 
@@ -87,12 +86,12 @@ class AndOp(object):
         return all(self.rule_targets)
 
     def __str__(self):
-        return '(' + ' and '.join(six.moves.map(str, self.rule_targets)) + ')'
+        return '(' + ' and '.join(map(str, self.rule_targets)) + ')'
 
     __nonzero__ = __bool__
 
 
-class OrOp(object):
+class OrOp:
     def __init__(self, rule_targets):
         self.rule_targets = rule_targets
 
@@ -100,14 +99,14 @@ class OrOp(object):
         return any(self.rule_targets)
 
     def __str__(self):
-        return '(' + ' or '.join(six.moves.map(str, self.rule_targets)) + ')'
+        return '(' + ' or '.join(map(str, self.rule_targets)) + ')'
 
     __nonzero__ = __bool__
 
 
 class CompositeEvaluator(evaluator.Evaluator):
     def __init__(self, conf):
-        super(CompositeEvaluator, self).__init__(conf)
+        super().__init__(conf)
         self.conf = conf
         self._threshold_evaluators = None
         self.rule_targets = []
@@ -117,7 +116,8 @@ class CompositeEvaluator(evaluator.Evaluator):
     @property
     def threshold_evaluators(self):
         if not self._threshold_evaluators:
-            threshold_types = ('gnocchi_resources_threshold',
+            threshold_types = ('prometheus',
+                               'gnocchi_resources_threshold',
                                'gnocchi_aggregation_by_metrics_threshold',
                                'gnocchi_aggregation_by_resources_threshold')
             self._threshold_evaluators = stevedore.NamedExtensionManager(
@@ -158,7 +158,7 @@ class CompositeEvaluator(evaluator.Evaluator):
             self.rule_targets.append(rule)
             return AlarmEvaluation(rule), OkEvaluation(rule)
         else:
-            LOG.error("Invalid rule type: %s" % alarm_rule['type'])
+            LOG.error("Invalid rule type: %s", alarm_rule['type'])
             return False, False
 
     def _reason(self, alarm, new_state, rule_target_alarm):
