@@ -36,6 +36,7 @@ COMPARATORS = {
 OPTS = [
     cfg.IntOpt('additional_ingestion_lag',
                min=0,
+               max=3600 * 24,
                default=0,
                help='The number of seconds to extend the evaluation windows '
                'to compensate the reporting/ingestion lag.')
@@ -46,7 +47,7 @@ class InsufficientDataError(Exception):
     def __init__(self, reason, statistics):
         self.reason = reason
         self.statistics = statistics
-        super(InsufficientDataError, self).__init__(reason)
+        super().__init__(reason)
 
 
 class ThresholdEvaluator(evaluator.Evaluator):
@@ -176,3 +177,7 @@ class ThresholdEvaluator(evaluator.Evaluator):
             evaluation = (evaluator.UNKNOWN, None, e.statistics, 0,
                           e.reason)
         self._transition_alarm(alarm, *evaluation)
+        if evaluation[0] is not None:
+            self._increment_evaluation_result(alarm.alarm_id,
+                                              alarm.project_id,
+                                              evaluation[0].replace(" ", "_"))
