@@ -54,7 +54,7 @@ class RestAlarmNotifier(notifier.AlarmNotifier):
     """Rest alarm notifier."""
 
     def __init__(self, conf):
-        super(RestAlarmNotifier, self).__init__(conf)
+        super().__init__(conf)
         self.conf = conf
 
     def notify(self, action, alarm_id, alarm_name, severity, previous,
@@ -67,11 +67,11 @@ class RestAlarmNotifier(notifier.AlarmNotifier):
         LOG.info(
             "Notifying alarm %(alarm_name)s %(alarm_id)s with severity"
             " %(severity)s from %(previous)s to %(current)s with action "
-            "%(action)s because %(reason)s. request-id: %(request_id)s " %
-            ({'alarm_name': alarm_name, 'alarm_id': alarm_id,
-              'severity': severity, 'previous': previous,
-              'current': current, 'action': action, 'reason': reason,
-              'request_id': headers['x-openstack-request-id']}))
+            "%(action)s because %(reason)s. request-id: %(request_id)s",
+            {'alarm_name': alarm_name, 'alarm_id': alarm_id,
+             'severity': severity, 'previous': previous,
+             'current': current, 'action': action, 'reason': reason,
+             'request_id': headers['x-openstack-request-id']})
         body = {'alarm_name': alarm_name, 'alarm_id': alarm_id,
                 'severity': severity, 'previous': previous,
                 'current': current, 'reason': reason,
