@@ -14,13 +14,13 @@
 # under the License.
 """Rest alarm notifier with trusted authentication."""
 
-from six.moves.urllib import parse
+from urllib import parse
 
 from aodh import keystone_client
 from aodh.notifier import rest
 
 
-class TrustAlarmNotifierMixin(object):
+class TrustAlarmNotifierMixin:
     """Mixin class to add Keystone trust support to an AlarmNotifier.
 
     Provides a notify() method that interprets the trust ID and then calls
@@ -43,7 +43,7 @@ class TrustAlarmNotifierMixin(object):
                                    action.fragment)
 
         headers = {'X-Auth-Token': keystone_client.get_auth_token(client)}
-        super(TrustAlarmNotifierMixin, self).notify(
+        super().notify(
             action, alarm_id, alarm_name, severity, previous, current, reason,
             reason_data, headers)
 
@@ -55,5 +55,5 @@ class TrustRestAlarmNotifier(TrustAlarmNotifierMixin, rest.RestAlarmNotifier):
     keystone authentication. It uses the aodh service user to
     authenticate using the trust ID provided.
 
-    The URL must be in the form ``trust+http://trust-id@host/action``.
+    The URL must be in the form ``trust+http://host/action``.
     """
