@@ -33,22 +33,11 @@ from aodh import version
 
 profiler_opts = importutils.try_import('osprofiler.opts')
 
-OPTS = [
-    cfg.IntOpt('http_timeout',
-               default=600,
-               deprecated_for_removal=True,
-               deprecated_reason=('This parameter is not used now and has no '
-                                  'effect.'),
-               help='Timeout seconds for HTTP requests. Set it to None to '
-                    'disable timeout.'),
-]
-
 EVALUATOR_OPTS = [
     cfg.IntOpt('workers',
                default=1,
                min=1,
-               help='Number of workers for evaluator service. '
-               'default value is 1.'),
+               help='Number of workers for evaluator service.'),
     cfg.IntOpt('evaluation_interval',
                default=60,
                deprecated_group='DEFAULT',
@@ -61,20 +50,18 @@ NOTIFIER_OPTS = [
     cfg.IntOpt('workers',
                default=1,
                min=1,
-               help='Number of workers for notifier service. '
-               'default value is 1.')
+               help='Number of workers for notifier service.')
 ]
 
 LISTENER_OPTS = [
     cfg.IntOpt('workers',
                default=1,
                min=1,
-               help='Number of workers for listener service. '
-                    'default value is 1.')
+               help='Number of workers for listener service.')
 ]
 
 
-def prepare_service(argv=None, config_files=None):
+def prepare_service(argv=None, config_files=None, with_gmr=True):
     conf = cfg.ConfigOpts()
     oslo_i18n.enable_lazy()
     log.register_options(conf)
@@ -108,9 +95,9 @@ def prepare_service(argv=None, config_files=None):
     ka_loading.load_auth_from_conf_options(conf, "service_credentials")
     log.setup(conf, 'aodh')
 
-    # NOTE(tkajinam): guru cannot run with service under apache daemon, so when
-    # aod-api running with mod_wsgi, the argv is [], we don't start guru.
-    if argv:
+    # NOTE(tkajinam): disable GMR when app is run by mod_wsgi/uwsgi because
+    # signal handler can't be installed.
+    if with_gmr:
         gmr_opts.set_defaults(conf)
         gmr.TextGuruMeditation.setup_autorun(version, conf=conf)
 
