@@ -15,9 +15,9 @@
 """Base classes for storage engines
 """
 import copy
+import inspect
 
 import aodh
-from aodh.utils import get_func_valid_keys
 
 
 def update_nested(original_dict, updates):
@@ -35,7 +35,7 @@ def update_nested(original_dict, updates):
     return dict_to_update
 
 
-class Model(object):
+class Model:
     """base class for storage api models."""
 
     def __init__(self, **kwds):
@@ -62,11 +62,11 @@ class Model(object):
 
     @classmethod
     def get_field_names(cls):
-        fields = get_func_valid_keys(cls.__init__)
-        return set(fields) - set(["self"])
+        fields = inspect.getfullargspec(cls.__init__)[0]
+        return set(fields) - {"self"}
 
 
-class Connection(object):
+class Connection:
     """Base class for alarm storage system connections."""
 
     # A dictionary representing the capabilities of this driver.
@@ -111,6 +111,16 @@ class Connection(object):
         """Delete an alarm and its history data."""
         raise aodh.NotImplementedError('Alarms not implemented')
 
+    @staticmethod
+    def increment_alarm_counter(alarm_id, project_id, state):
+        """Increment a counter."""
+        raise aodh.NotImplementedError('Alarm counters not implemented')
+
+    @staticmethod
+    def get_alarm_counters(alarm_id=None, project_id=None, state=None):
+        """Get value of a counter."""
+        raise aodh.NotImplementedError('Alarm counters not implemented')
+
     @staticmethod
     def get_alarm_changes(alarm_id, on_behalf_of,
                           user=None, project=None, alarm_type=None,
