@@ -81,7 +81,7 @@ class TestBase(test_base.BaseTestCase,
     }
 
     def setUp(self):
-        super(TestBase, self).setUp()
+        super().setUp()
 
         db_url = os.environ.get(
             'AODH_TEST_STORAGE_URL', 'sqlite://',
@@ -96,6 +96,7 @@ class TestBase(test_base.BaseTestCase,
         conf = service.prepare_service(argv=[], config_files=[])
         self.CONF = self.useFixture(fixture_config.Config(conf)).conf
         self.CONF.set_override('connection', db_url, group="database")
+        self.CONF.set_override('enable_evaluation_results_metrics', True)
 
         manager = self.DRIVER_MANAGERS.get(self.engine)
         if not manager:
@@ -118,7 +119,7 @@ class TestBase(test_base.BaseTestCase,
     def tearDown(self):
         self.alarm_conn.clear()
         self.alarm_conn = None
-        super(TestBase, self).tearDown()
+        super().tearDown()
 
     def _get_connection(self, conf):
         return self.alarm_conn
