@@ -13,8 +13,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import datetime
+from unittest import mock
 
-import mock
 from oslo_utils import timeutils
 from oslotest import base
 
@@ -24,7 +24,7 @@ from aodh import queue
 
 class TestEvaluatorBaseClass(base.BaseTestCase):
     def setUp(self):
-        super(TestEvaluatorBaseClass, self).setUp()
+        super().setUp()
         self.called = False
 
     def _notify(self, alarm, previous, reason, details):
