@@ -12,7 +12,8 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import mock
+from unittest import mock
+
 from oslo_utils import netutils
 
 from aodh.notifier import heat as heat_notifier
@@ -37,7 +38,7 @@ class TestTrustHeatAlarmNotifier(base.TestNotifierBase):
             ]
         }
 
-        class FakeResource(object):
+        class FakeResource:
             def __init__(self, resource_name):
                 self.parent_resource = resource_name
 
